Skip to contents

Downloads a pre-built SpatVector containing IUCN range polygons for all Rodentia species recorded in Mexico.

Usage

get_rodentia_mexico()

Robles-Fernandez, A. L., Lira-Noriega, A., & Martinez-Meyer, E. (2023). A phylogeny-informed characterisation of global tetrapod traits addresses data gaps and biases. doi:10.1101/2023.03.04.531098

Value

A SpatVector object, or "Can't access data." if the remote server is unreachable.

Examples

# \donttest{
shp <- get_rodentia_mexico()
# }