| platt_generate_regression_ETR_II | R Documentation |
Fits the Platt (1980) regression model using original naming conventions.
platt_generate_regression_ETR_II(
data,
alpha_start_value = platt_default_start_value_alpha,
beta_start_value = platt_default_start_value_beta,
ps_start_value = platt_default_start_value_ps
)
data |
A |
alpha_start_value |
Numeric. Initial value for |
beta_start_value |
Numeric. Initial value for |
ps_start_value |
Numeric. Initial value for |
A detailed documentation can be found under https://github.com/biotoolbox/pam/tree/main#functions.
A list containing:
etr_regression_data: Predicted ETR values.
residual_sum_of_squares: Difference between observed and predicted ETR values, expressed as the sum of squared residuals.
root_mean_squared_error: Difference between observed and predicted ETR values, expressed as the root mean squared error.
relative_root_mean_squared_error: Difference between observed and predicted ETR values, expressed as the relative root mean squared error, normalized by the mean.
ps: Maximum electron transport rate without photoinhibition (P_s).
alpha: Initial slope of the light curve (\alpha).
beta: Photoinhibition (\beta).
pm: Maximum electron transport rate with photoinhibition (P_m).
ik: Transition PAR with photoinhibition (I_k).
is: Transition PAR without photoinhibition (I_s).
im: PAR at maximum ETR with photoinhibition (I_m).
ib: (I_b)
Platt, T., Gallegos, C. L., & Harrison, W. G. (1980). Photoinhibition of photosynthesis in natural assemblages of marine phytoplankton. Journal of Marine Research, 38(4). Retrieved from https://elischolar.library.yale.edu/journal_of_marine_research/1525/.
path <- file.path(system.file("extdata/dual_pam_data", package = "pam"), "20240925.csv")
data <- read_dual_pam_data(path)
result <- platt_generate_regression_ETR_II(data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.