View source: R/model_vollenweider.R
| vollenweider_generate_regression_ETR_II | R Documentation |
Fits the Vollenweider (1965) regression model using original naming conventions from the publication.
vollenweider_generate_regression_ETR_II(
data,
pmax_start_value = vollenweider_default_start_value_pmax,
a_start_value = vollenweider_default_start_value_a,
alpha_start_value = vollenweider_default_start_value_alpha,
n_start_value = vollenweider_default_start_value_n
)
data |
A |
pmax_start_value |
Numeric. Initial value for |
a_start_value |
Numeric. Initial value for |
alpha_start_value |
Numeric. Initial value for |
n_start_value |
Numeric. Initial value for |
A detailed documentation can be found under https://github.com/biotoolbox/pam/tree/main#functions.
A list containing:
etr_regression_data: Predicted ETR values.
residual_sum_of_squares: Difference between observed and predicted ETR values, expressed as the sum of squared residuals.
root_mean_squared_error: Difference between observed and predicted ETR values, expressed as the root mean squared error.
relative_root_mean_squared_error: Difference between observed and predicted ETR values, expressed as the relative root mean squared error, normalized by the mean.
pmax: Maximum electron transport rate without photoinhibition (p_{max}).
a: Parameter a.
alpha: Parameter \alpha.
n: Parameter n.
popt: Maximum electron transport rate with photoinhibition (p_{opt}).
ik: Transition point from light limitation to light saturation without photoinhibition (I_k).
iik: Transition point from light limitation to light saturation with photoinhibition (I_k^\prime).
pmax_popt_and_ik_iik_ratio: Ratio of p_{max} / p_{opt} and I_k / I_k^\prime.
Vollenweider, R. A. (1965). Calculation models of photosynthesis-depth curves and some implications regarding day rate estimates in primary production measurements, p. 427-457. In C. R. Goldman [ed.], Primary Productivity in Aquatic Environments. Mem. Ist. Ital. Idrobiol., 18 Suppl., University of California Press, Berkeley.
path <- file.path(system.file("extdata/dual_pam_data", package = "pam"), "20240925.csv")
data <- read_dual_pam_data(path)
result <- vollenweider_generate_regression_ETR_II(data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.