vollenweider_modified: Vollenweider Model Modification

View source: R/model_vollenweider.R

vollenweider_modifiedR Documentation

Vollenweider Model Modification

Description

This function adds parameters that were not originally included in the Vollenweider (1965) model, but were introduced by other models, and renames the parameters to a standardized one for all models.

Usage

vollenweider_modified(model_result)

Arguments

model_result

A list containing the model result (e.g. from vollenweider_generate_regression_ETR_II()).

Details

A detailed documentation can be found under https://github.com/biotoolbox/pam?tab=readme-ov-file#vollenweider_modified

Value

A modified model result as a list containing the following elements:

  • etr_type: ETR Type based on the model result.

  • etr_regression_data: Regression data with ETR predictions based on the fitted model.

  • residual_sum_of_squares: Difference between observed and predicted ETR values, expressed as the sum of squared residuals.

  • root_mean_squared_error: Difference between observed and predicted ETR values, expressed as the root mean squared error.

  • relative_root_mean_squared_error: Difference between observed and predicted ETR values, expressed as the relative root mean squared error, normalized by the mean.

  • a: Obtained parameter a, here equal to etrmax_without_photoinhibition.

  • b: Obtained parameter b, transferred as a.

  • c: Obtained parameter c, here transferred as alpha.

  • d: Obtained parameter d, here transferred as n.

  • alpha: The initial slope of the light curve.

  • beta: Not available, here set to NA_real_.

  • etrmax_with_photoinhibition: The maximum electron transport rate with photoinhibition, transferred as popt.

  • etrmax_without_photoinhibition: The maximum electron transport rate without photoinhibition, transferred as pmax.

  • ik_with_photoinhibition: PAR where the transition point from light limitation to light saturation is achieved taking photoinhibition into account, transferred as iik.

  • ik_without_photoinhibition: PAR where the transition point from light limitation to light saturation is achieved not taking photoinhibition into account, transferred as ik.

  • im_with_photoinhibition: The PAR at which the maximum electron transport rate is achieved by taking photoinhibition into account, determined using the regression data from the model.

  • w: Not available, here set to NA_real_.

  • ib: Transferred unchanged as ib.

  • etrmax_without_with_ratio: Ratio of etrmax_without_photoinhibition / etrmax_with_photoinhibition and ik_without_photoinhibition / ik_with_photoinhibition.

Examples

path <- file.path(system.file("extdata/dual_pam_data", package = "pam"), "20240925.csv")
data <- read_dual_pam_data(path)

result <- vollenweider_generate_regression_ETR_II(data)
modified_result <- vollenweider_modified(result)


pam documentation built on April 30, 2026, 5:06 p.m.