walsby_generate_regression_ETR_I: Walsby Regression for ETR I

View source: R/model_walsby.R

walsby_generate_regression_ETR_IR Documentation

Walsby Regression for ETR I

Description

Fits a modified Walsby (1997) regression model without the respiration term, using Romoth (2019) naming conventions. Calculates ETR_{max} without accounting for photoinhibition.

Usage

walsby_generate_regression_ETR_I(
  data,
  etr_max_start_value = walsby_default_start_value_etr_max,
  alpha_start_value = walsby_default_start_value_alpha,
  beta_start_value = walsby_default_start_value_beta
)

Arguments

data

A data.table from read function (e.g.read_dual_pam_data).

etr_max_start_value

Numeric. Initial value for ETR_{max}. Default: etr_max_start_value_walsby_default.

alpha_start_value

Numeric. Initial value for \alpha. Default: alpha_start_value_walsby_default.

beta_start_value

Numeric. Initial value for \beta. Default: beta_start_value_walsby_default.

Details

A detailed documentation can be found under https://github.com/biotoolbox/pam/tree/main#functions.

Value

A list containing:

  • etr_regression_data: Predicted ETR values.

  • residual_sum_of_squares: Difference between observed and predicted ETR values, expressed as the sum of squared residuals.

  • root_mean_squared_error: Difference between observed and predicted ETR values, expressed as the root mean squared error.

  • relative_root_mean_squared_error: Difference between observed and predicted ETR values, expressed as the relative root mean squared error, normalized by the mean.

  • etr_max: Maximum ETR (ETR_{max}).

  • alpha: Initial slope (\alpha).

  • beta: Photoinhibition factor (\beta).

References

Walsby, A. E. (1997). Numerical integration of phytoplankton photosynthesis through time and depth in a water column. New Phytologist, 136(2), 189-209. Available at: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1046/j.1469-8137.1997.00736.x")}

Romoth, K., Nowak, P., Kempke, D., Dietrich, A., Porsche, C., & Schubert, H. (2019). Acclimation limits of Fucus evanescens along the salinity gradient of the southwestern Baltic Sea. Botanica Marina, 62(1), 1-12. Available at: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1515/bot-2018-0098")}

Examples

path <- file.path(system.file("extdata/dual_pam_data", package = "pam"), "20240925.csv")
data <- read_dual_pam_data(path)

result <- walsby_generate_regression_ETR_I(data)


pam documentation built on April 30, 2026, 5:06 p.m.