etr_type: ETR Type based on the model result.
etr_regression_data: Regression data with ETR predictions based on the fitted model.
sdiff: The difference between observed and predicted ETR values.
a: Obtained parameter a, here equal to etrmax_without_photoinhibition.
b: Obtained parameter b, transferred as a.
c: Obtained parameter c, here transferred as alpha.
d: Obtained parameter d, here transferred as n.
alpha: The initial slope of the light curve.
beta: Not available, here set to NA_real_.
etrmax_with_photoinhibition: The maximum electron transport rate with photoinhibition, transferred as popt.
etrmax_without_photoinhibition: The maximum electron transport rate without photoinhibition, transferred as pmax.
ik_with_photoinhibition: PAR where the transition point from light limitation to light saturation is achieved taking photoinhibition into account, transferred as iik.
ik_without_photoinhibition: PAR where the transition point from light limitation to light saturation is achieved not taking photoinhibition into account, transferred as ik.
im_with_photoinhibition: The PAR at which the maximum electron transport rate is achieved by taking photoinhibition into account, determined using the regression data from the model.
w: Not available, here set to NA_real_.
ib: Transferred unchanged as ib.
etrmax_with_without_ratio: Ratio of etrmax_with_photoinhibition to etrmax_without_photoinhibition and ik_with_photoinhibition to ik_without_photoinhibition.